CREATE TABLE `actions` (
  `action` varchar(100) NOT NULL DEFAULT '',
  `file` varchar(100) NOT NULL DEFAULT '',
  `title` varchar(100) NOT NULL DEFAULT '',
  `right` int(1) NOT NULL DEFAULT '0',
  `box` varchar(500) DEFAULT NULL,
  `sub` varchar(25) NOT NULL DEFAULT 'main',
  `id` int(11) NOT NULL AUTO_INCREMENT,
  PRIMARY KEY (`id`)
) ENGINE=MyISAM AUTO_INCREMENT=150 DEFAULT CHARSET=utf8;
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('showLogin','exploit.pl','','0','tables','main','147');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('AddFulltext','tables.pl','AddFulltext','5','tables','AddFulltext','62');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('AnalyzeTable','tables.pl','AnalyzeTable','5','tables','AnalyzeTable','63');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('AddPrimaryKey','tables.pl','AddPrimaryKey','5','tables','AddPrimaryKey','64');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ChangeEngine','tables.pl','ChangeEngine','5','tables','ChangeEngine','65');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ChangeAutoInCrementValue','tables.pl','ChangeAutoInCrementValue','5','tables','ChangeAutoInCrementValue','66');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ChangeCol','tables.pl','ChangeCol','5','tables','ChangeCol','67');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ChangeEngine','tables.pl','ChangeEngine','5','tables','ChangeEngine','68');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ChangeCharset','tables.pl','ChangeCharset','5','tables','ChangeCharset','69');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ChangeAutoInCrementValue','tables.pl','ChangeAutoInCrementValue','5','tables','ChangeAutoInCrementValue','70');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ChooseDataBase','tables.pl','ChooseDataBase','5','tables','ChooseDataBase','71');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('DropTable','tables.pl','DropTable','5','tables','DropTable','72');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('DeleteEntry','tables.pl','DeleteEntry','5','tables','DeleteEntry','73');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('DropCol','tables.pl','DropCol','5','tables','DropCol','74');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowDumpTable','tables.pl','DumpTable','5','tables','ShowDumpTable','75');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ExecSql','tables.pl','ExecSql','5','tables','ExecSql','76');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('EditTable','tables.pl','SQL','5','tables','EditTable','77');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('EditEntry','tables.pl','EditEntry','5','tables','EditEntry','78');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('NewEntry','tables.pl','NewEntry','5','tables','NewEntry','79');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('NewTable','tables.pl','NewTable','5','tables','NewTable','80');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('CreateDatabase','tables.pl','CreateDatabase','5','tables','CreateDatabase','81');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('OptimizeTable','tables.pl','OptimizeTable','5','tables','OptimizeTable','82');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('RepairTable','tables.pl','RepairTable','5','tables','RepairTable','84');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('SaveEditTable','tables.pl','SaveEditTable','5','tables','SaveEditTable','85');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('SQL','tables.pl','SQL','5','tables','SQL','86');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowNewTable','tables.pl','ShowNewTable','5','tables','ShowNewTable','87');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('SaveEntry','tables.pl','SaveEntry','5','tables','SaveEntry','88');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('DropFulltext','tables.pl','DropFulltext','5','tables','DropFulltext','89');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowTables','tables.pl','ShowTables','5','tables','ShowTables','90');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowTableDetails','tables.pl','ShowTableDetails','5','tables','ShowTableDetails','91');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowTable','tables.pl','ShowTable','5','tables','ShowTable','92');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('TruncateTable','tables.pl','TruncateTable','5','tables','TruncateTable','93');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowProcesslist','tables.pl','ShowProcesslist','5','tables','ShowProcesslist','94');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('DropFulltext','tables.pl','DropFulltext','5','tables','DropFulltext','95');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('AddIndex','tables.pl','DropFulltext','5','tables','AddIndex','96');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('DropIndex','tables.pl','DropFulltext','5','tables','DropIndex','97');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('AddUnique','tables.pl','DropFulltext','5','tables','AddUnique','98');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowNewEntry','tables.pl','ShowNewEntry','5','tables','ShowNewEntry','99');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('SaveEntry','tables.pl','SaveEntry','5','tables','SaveEntry','100');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('NewEntry','tables.pl','NewEntry','5','tables','NewEntry','101');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('DeleteEntry','tables.pl','DeleteEntry','5','tables','DeleteEntry','102');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('MultipleAction','tables.pl','MultipleAction','5','tables','MultipleAction','104');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowDumpDatabase','tables.pl','DumpDatabase','5','tables','ShowDumpDatabase','105');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowNewTable','tables.pl','ShowNewTable','5','tables','ShowNewTable','106');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('SaveNewTable','tables.pl','SaveNewTable','5','tables','SaveNewTable','107');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('EditAction','tables.pl','EditAction','5','tables','EditAction','111');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('showProfile','profile.pl','showProfile','5','','showProfile','148');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('MultipleDbAction','tables.pl','MultipleDbAction','5','tables','MultipleDbAction','118');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('RenameTable','tables.pl','RenameTable','5','tables','RenameTable','119');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('SaveNewColumn','tables.pl','SaveNewColumn','5','tables','SaveNewColumn','120');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('NewDatabase','tables.pl','NewDatabase','5','tables','NewDatabase','121');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowEditIndex','tables.pl','ShowEditIndex','5','tables','ShowEditIndex','122');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('SaveNewIndex','tables.pl','SaveNewIndex','5','tables','SaveNewIndex','123');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ChangeEngine','tables.pl','ChangeEngine','5','tables','ChangeEngine','124');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ChangeAutoInCrementValue','tables.pl','ChangeEngine','5','tables','ChangeAutoInCrementValue','125');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowRights','tables.pl','ShowRights','5','tables','ShowRights','127');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('SaveRights','tables.pl','SaveRights','5','tables','SaveRights','128');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowUsers','tables.pl','ShowUsers','5','tables','ShowUsers','129');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('CreateUser','tables.pl','CreateUser','5','tables','CreateUser','130');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('DeleteUser','tables.pl','DeleteUser','5','tables','DeleteUser','131');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('DropDatabase','tables.pl','DropDatabase','5','tables','DropDatabase','132');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowDatabases','tables.pl','ShowDatabases','5','tables exploit','ShowDatabases','133');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowProcesslist','tables.pl','ShowProcesslist','5','tables','ShowProcesslist','134');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowVariables','tables.pl','ShowVariables','5','tables','ShowVariables','135');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('translate','translate.pl','translate','5','tables','main','141');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowProcesslist','tables.pl','processlist','5','tables','ShowProcesslist','143');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('ShowVariables','tables.pl','ShowVariables','5','tables','ShowVariables','144');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('searchDatabase','tables.pl','searchDatabase','5','tables','searchDatabase','145');
INSERT INTO `actions` (`action`,`file`,`title`,`right`,`box`,`sub`,`id`) values('saveProfile','profile.pl','Profile','5','','saveProfile','149');

CREATE TABLE `box` (
  `file` varchar(100) NOT NULL DEFAULT '',
  `right` int(1) NOT NULL DEFAULT '0',
  `name` varchar(100) NOT NULL DEFAULT '',
  `outId` varchar(100) NOT NULL DEFAULT 'content',
  `id` int(11) NOT NULL AUTO_INCREMENT,
  PRIMARY KEY (`id`)
) ENGINE=MyISAM AUTO_INCREMENT=12 DEFAULT CHARSET=utf8;
INSERT INTO `box` (`file`,`right`,`name`,`outId`,`id`) values('tables.pl','5','database','menuBar','10');
INSERT INTO `box` (`file`,`right`,`name`,`outId`,`id`) values('exploit.pl','0','exploit','content','11');

CREATE TABLE `exploit` (
  `date` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `referer` text NOT NULL,
  `remote_addr` text NOT NULL,
  `query_string` text NOT NULL,
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `count` int(11) NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `id` (`id`),
  FULLTEXT KEY `remote_addr` (`remote_addr`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

CREATE TABLE `querys` (
  `title` varchar(100) NOT NULL DEFAULT '',
  `description` text NOT NULL,
  `sql` text NOT NULL,
  `return` varchar(100) NOT NULL DEFAULT 'fetch_array',
  `id` int(11) NOT NULL AUTO_INCREMENT,
  PRIMARY KEY (`id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

CREATE TABLE `reserved_words` (
  `reserved_word` varchar(50) DEFAULT NULL,
  `id` int(11) NOT NULL AUTO_INCREMENT,
  PRIMARY KEY (`id`)
) ENGINE=MyISAM AUTO_INCREMENT=224 DEFAULT CHARSET=latin1;
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ACCESSIBLE','1');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ALTER','2');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('AS','3');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('BEFORE','4');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('BINARY','5');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('BY','6');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CASE','7');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CHARACTER','8');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('COLUMN','9');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CONTINUE','10');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CROSS','11');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CURRENT_TIMESTAMP','12');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DATABASE','13');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DAY_MICROSECOND','14');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DEC','15');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DEFAULT','16');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DESC','17');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DISTINCT','18');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DOUBLE','19');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('EACH','20');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ENCLOSED','21');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('EXIT','22');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('FETCH','23');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('FLOAT8','24');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('FOREIGN','25');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('GRANT','26');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('HIGH_PRIORITY','27');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('HOUR_SECOND','28');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('IN','29');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INNER','30');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INSERT','31');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INT2','32');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INT8','33');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INTO','34');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('JOIN','35');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('KILL','36');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LEFT','37');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LINEAR','38');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LOCALTIME','39');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LONG','40');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LOOP','41');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('MATCH','42');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('MEDIUMTEXT','43');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('MINUTE_SECOND','44');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('NATURAL','45');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('NULL','46');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('OPTIMIZE','47');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('OR','48');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('OUTER','49');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('PRIMARY','50');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('RANGE','51');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('READ_WRITE','52');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('REGEXP','53');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('REPEAT','54');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('RESTRICT','55');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('RIGHT','56');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SCHEMAS','57');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SENSITIVE','58');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SHOW','59');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SPECIFIC','60');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SQLSTATE','61');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SQL_CALC_FOUND_ROWS','62');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('STARTING','63');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('TERMINATED','64');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('TINYINT','65');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('TRAILING','66');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('UNDO','67');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('UNLOCK','68');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('USAGE','69');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('UTC_DATE','70');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('VALUES','71');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('VARCHARACTER','72');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('WHERE','73');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('WRITE','74');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ZEROFILL','75');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ALL','76');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('AND','77');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ASENSITIVE','78');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('BIGINT','79');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('BOTH','80');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CASCADE','81');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CHAR','82');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('COLLATE','83');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CONSTRAINT','84');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CREATE','85');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CURRENT_TIME','86');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CURSOR','87');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DAY_HOUR','88');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DAY_SECOND','89');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DECLARE','90');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DELETE','91');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DETERMINISTIC','92');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DIV','93');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DUAL','94');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ELSEIF','95');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('EXISTS','96');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('FALSE','97');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('FLOAT4','98');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('FORCE','99');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('FULLTEXT','100');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('HAVING','101');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('HOUR_MINUTE','102');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('IGNORE','103');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INFILE','104');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INSENSITIVE','105');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INT1','106');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INT4','107');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INTERVAL','108');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ITERATE','109');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('KEYS','110');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LEAVE','111');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LIMIT','112');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LOAD','113');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LOCK','114');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LONGTEXT','115');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('MASTER_SSL_VERIFY_SERVER_CERT','116');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('MEDIUMINT','117');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('MINUTE_MICROSECOND','118');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('MODIFIES','119');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('NO_WRITE_TO_BINLOG','120');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ON','121');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('OPTIONALLY','122');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('OUT','123');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('PRECISION','124');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('PURGE','125');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('READS','126');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('REFERENCES','127');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('RENAME','128');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('REQUIRE','129');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('REVOKE','130');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SCHEMA','131');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SELECT','132');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SET','133');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SPATIAL','134');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SQLEXCEPTION','135');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SQL_BIG_RESULT','136');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SSL','137');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('TABLE','138');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('TINYBLOB','139');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('TO','140');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('TRUE','141');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('UNIQUE','142');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('UPDATE','143');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('USING','144');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('UTC_TIMESTAMP','145');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('VARCHAR','146');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('WHEN','147');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('WITH','148');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('YEAR_MONTH','149');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ADD','150');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ANALYZE','151');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ASC','152');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('BETWEEN','153');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('BLOB','154');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CALL','155');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CHANGE','156');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CHECK','157');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CONDITION','158');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CONVERT','159');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CURRENT_DATE','160');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('CURRENT_USER','161');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DATABASES','162');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DAY_MINUTE','163');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DECIMAL','164');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DELAYED','165');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DESCRIBE','166');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DISTINCTROW','167');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('DROP','168');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ELSE','169');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ESCAPED','170');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('EXPLAIN','171');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('FLOAT','172');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('FOR','173');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('FROM','174');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('GROUP','175');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('HOUR_MICROSECOND','176');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('IF','177');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INDEX','178');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INOUT','179');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INT','180');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INT3','181');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('INTEGER','182');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('IS','183');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('KEY','184');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LEADING','185');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LIKE','186');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LINES','187');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LOCALTIMESTAMP','188');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LONGBLOB','189');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('LOW_PRIORITY','190');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('MEDIUMBLOB','191');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('MIDDLEINT','192');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('MOD','193');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('NOT','194');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('NUMERIC','195');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('OPTION','196');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('ORDER','197');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('OUTFILE','198');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('PROCEDURE','199');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('READ','200');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('REAL','201');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('RELEASE','202');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('REPLACE','203');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('RETURN','204');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('RLIKE','205');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SECOND_MICROSECOND','206');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SEPARATOR','207');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SMALLINT','208');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SQL','209');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SQLWARNING','210');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('SQL_SMALL_RESULT','211');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('STRAIGHT_JOIN','212');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('THEN','213');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('TINYTEXT','214');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('TRIGGER','215');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('UNION','216');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('UNSIGNED','217');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('USE','218');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('UTC_TIME','219');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('VARBINARY','220');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('VARYING','221');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('WHILE','222');
INSERT INTO `reserved_words` (`reserved_word`,`id`) values('XOR','223');
CREATE TABLE `users` (
  `pass` text NOT NULL,
  `user` varchar(10) NOT NULL,
  `right` int(1) NOT NULL DEFAULT '0',
  `sid` varchar(200) DEFAULT NULL,
  `ip` varchar(50) DEFAULT NULL,
  `id` int(11) NOT NULL AUTO_INCREMENT,
  PRIMARY KEY (`id`)
) ENGINE=MyISAM AUTO_INCREMENT=7 DEFAULT CHARSET=utf8;
INSERT INTO `users` (`pass`,`user`,`right`,`sid`,`ip`,`id`) values('guest','guest','0','123','dd','1');