$VAR1 = {
          'en' => {
                    'createindex' => 'New Index',
                    'details' => 'Details',
                    'create' => 'Create',
                    'changeengine' => 'Change Engine',
                    'showtables' => 'Tables',
                    'limit' => 'Limit',
                    'truncate' => 'Truncate',
                    'connect' => 'Connect',
                    'table' => 'Table',
                    'editmysqluserrights' => 'Rights',
                    'show' => 'Show',
                    'type' => 'Type',
                    'optimize' => 'Optimize',
                    'newcol' => 'New Column',
                    'edittableprops' => 'Table',
                    'rename' => 'Rename',
                    'database' => 'Database',
                    'collation' => 'Collation',
                    'databases' => 'Databases',
                    'wrong_passwort_text' => 'The password must be at least 6 characters in length.',
                    'edit' => 'Edit',
                    'size' => 'Size',
                    'newentry' => 'New Entry',
                    'editentry' => 'Edit Entry',
                    'name' => 'Name',
                    'comment' => 'Comment',
                    'password' => 'Password',
                    'repair' => 'Repair',
                    'endtable' => 'at end',
                    'right_passwort_text' => 'Ok',
                    'rowsineffect' => 'rows in effect',
                    'edittable' => 'Database',
                    'save' => 'Save',
                    'createuser' => 'Create User',
                    'createdatabase' => 'New Database',
                    'showdatabases' => 'Databases',
                    'sql' => 'SQL',
                    'optimizetable' => 'Optimize Table',
                    'changecurrentdb' => 'Change Database connection',
                    'insertafter' => 'After',
                    'indexover' => 'Index over',
                    'wrong_username_text' => 'The Username must be at least 3 characters in length and can only contain letters or digits.',
                    'changeautoincrementvalue' => 'Edit Table',
                    'createnewtable' => 'New Table',
                    'fields' => 'Fields',
                    'daten' => 'Data',
                    'delete' => 'Delete',
                    'export' => 'Export',
                    'showvariables' => 'Variables',
                    'analyzetable' => 'Analyze Table',
                    'processlist' => 'Processes',
                    'showsqlsearch' => 'Search in DB',
                    'links_pro_page' => 'links/page',
                    'selected' => 'Select all',
                    'logout' => 'Logout',
                    'exportdatabase' => 'Database',
                    'after' => 'after',
                    'showcreatetable' => 'New Table',
                    'login' => 'Login',
                    'repairtable' => 'Repair Table',
                    'showusers' => 'Show Users',
                    'execsql' => 'Exec Sql',
                    'regexp' => 'Regular Expression',
                    'select_all' => 'Select All',
                    'drop_database' => 'Drop Database',
                    'changecharset' => 'Change Charset',
                    'insert' => 'Insert',
                    'reg' => 'Register',
                    'showcreatedatabase' => 'New Database',
                    'user' => 'Username',
                    'unselect_all' => 'Unselect',
                    'showsqleditor' => 'Execute Sql',
                    'search' => 'Search',
                    'shownewentry' => 'New Entry',
                    'welcome' => 'Welcome',
                    'createtable' => 'New Table',
                    'showcreateuser' => 'New User',
                    'register' => 'Register',
                    'starttable' => 'at start',
                    'rights' => 'rights',
                    'field' => 'field',
                    'showchangecurrentdb' => 'Change ',
                    'host' => 'host',
                    'showprocesslist' => 'Processlist',
                    'showtable' => 'showtable',
                    'right_username_text' => 'Ok',
                    'showdumpdatabase' => 'Export',
                    'showdumptable' => 'Export',
                    'sqlsearch' => 'Search',                
                    'sqleditor' => 'Execute Sql',
                    'new' => 'New',
                    'ShowTableDetails' => 'Details',
		    'DropTable'=> 'Tables',
		    'DropDatabase'=> 'Databases',
		    'DeleteEntry'=> 'Table',
		    'SaveRights'=> 'Rights',		    
		    'codenotcheckedfileerror'=> '',
		    'failednotindatabase'=> '',
		    'failedinvalidcode'=> 'Failed invalid code',
                    'RenameTable'   => 'rename Table',
                    'showeditindex' => 'New Index',
                    'shownewrow'    => 'New Row',
		    'showProfile'=> 'Profile',
		    'saveProfile'=> 'Profile',
		    'retry'=> 'Retry',
		    'newpass'=> 'New Password',
                  },
          'de' => {
                    'host' => 'host',
                    'right_username_text' => 'Ok',
                    'showprocesslist' => 'Processe',
                    'showtable' => 'Tabelle',
                    'createtable' => 'Tabelle',
                    'showcreateuser' => 'Benutzer',
                    'welcome' => 'Willkommen',
                    'field' => 'Feld',
                    'showchangecurrentdb' => 'Datenbank wechseln',
                    'register' => 'Registrieren',
                    'starttable' => 'am Anfang',
                    'rights' => 'Rechte',
                    'search' => 'Suchen',
                    'showsqleditor' => 'SQL Ausführen',
                    'unselect_all' => 'Auswahl aufheben',
                    'shownewentry' => 'Neuer Eintrag',
                    'user' => 'Benutzer',
                    'reg' => 'Registrieren',
                    'showcreatedatabase' => 'Datenbank',
                    'select_all' => 'Alle auswählen',
                    'drop_database' => 'Datenbank löschen',
                    'regexp' => 'Regulärer Ausdruck',
                    'execsql' => 'Sql ausführen',
                    'showcreatetable' => 'Tabelle erstellen',
                    'after' => 'nach',
                    'showusers' => 'Benutzer',
                    'login' => 'Anmelden',
                    'repairtable' => 'Reparieren',
                    'insert' => 'Einfügen',
                    'changecharset' => 'Zeichensatz',
                    'showsqlsearch' => 'Suchen',
                    'links_pro_page' => 'Einträge/Seite',
                    'processlist' => 'Prozesse',
                    'exportdatabase' => 'Datenbank',
                    'logout' => 'Abmelden',
                    'selected' => 'Alle auswählen',
                    'showvariables' => 'Variablen',
                    'analyzetable' => 'Analysieren',
                    'fields' => 'Spalten',
                    'delete' => 'Löschen',
                    'daten' => 'Daten',
                    'changeautoincrementvalue' => 'Autoincrement',
                    'createnewtable' => 'Neue Tabelle',
                    'export' => 'Exportieren',
                    'optimizetable' => 'Optimieren',
                    'indexover' => 'Index über',
                    'wrong_username_text' => 'Der Benutzername muss mindestens 3 Zeichen lange sein und darf nur Ziffern und Buchstaben enthalten.',
                    'changecurrentdb' => 'Benutzer wechseln',
                    'insertafter' => 'Einfügen',
                    'createuser' => 'Neuer Benutzer',
                    'save' => 'Speichern',
                    'right_passwort_text' => 'Ok',
                    'rowsineffect' => 'betroffene Datensätze',
                    'edittable' => 'Bearbeiten',
                    'sql' => 'SQL',
                    'createdatabase' => 'Neue Datenbank',
                    'showdatabases' => 'Datenbanken',
                    'comment' => 'Kommentar',
                    'repair' => 'Reparieren',
                    'password' => 'Passwort',
                    'editentry' => 'Bearbeiten',
                    'name' => 'Name',
                    'endtable' => 'am ende',
                    'databases' => 'Datenbanken',
                    'collation' => 'Kollation',
                    'size' => 'Größe',
                    'newentry' => 'Neuer Eintrag',
                    'edit' => 'Bearbeiten',
                    'wrong_passwort_text' => 'Das Passwort muss mindestens 6 zeichen lang sein',
                    'edittableprops' => 'Bearbeiten',
                    'rename' => 'Umbenennen',
                    'RenameTable' => 'Tabelle umbenennen',
                    'showeditindex' => 'Index erstellen',
                    'shownewrow' => 'Neue Zeile',
                    'database' => 'Datenbank',
                    'editmysqluserrights' => 'Benutzerrechte',
                    'connect' => 'Verbinden',
                    'truncate' => 'Leeren',
                    'table' => 'Tabelle',
                    'type' => 'Type',
                    'optimize' => 'Optimieren',
                    'newcol' => 'Neue Zeile',
                    'show' => 'Anzeigen',
                    'create' => 'Erstellen',
                    'details' => 'Details',
                    'limit' => 'Limit',
                    'changeengine' => 'Engine',
                    'showtables' => 'Tabellen',
                    'createindex' => 'Index erstellen',
                    'showdumpdatabase' => 'Exportieren',
                    'showdumptable' => 'Exportieren',
                    'sqlsearch' => 'Suchen',                
                    'sqleditor' => 'Sql',
                    'new' => 'Neu',
                    'ShowTableDetails' => 'Details',
		    'DropTable'=> 'Tabellen',
		    'DropDatabase'=> 'Datenbanken',
		    'DeleteEntry'=> 'Tabelle',
		    'SaveRights'=> 'Rechte',
		    'codenotcheckedfileerror'=> '',
		    'failednotindatabase'=> '',
		    'failedinvalidcode'=> 'Falscher Code',
		    'showProfile'=> 'Profile',
		    'saveProfile'=> 'Profile',
		    'retry'=> 'Wiederhohlen',
		    'newpass'=> 'Neues Passwort',
                  }
        };
$lang =$VAR1;