my $remote_addr      = CGI::remote_addr()  ? CGI::remote_addr()  : 'none';
my $query_string = CGI::query_string() ? CGI::query_string() : 'none';
my $referer          = CGI::referer()      ? CGI::referer()      : 'none';
my @count = $m_oDatabase->fetch_array('select count(*) from exploit where `remote_addr` = ? && query_string = ? ',$remote_addr,$query_string);
if($count[0] eq 0){
  $m_oDatabase->void("INSERT INTO exploit(referer,remote_addr,query_string,count) VALUES (?,?,?,1)", $referer, $remote_addr, $query_string);
}else{
  $m_oDatabase->void("UPDATE exploit  set count =count+1 where remote_addr = ? && query_string = ?",$remote_addr,$query_string);
}
$m_sContent .= $@ if $@;
$m_sContent .= qq(<img src="images/preview.jpg" style="margin-top:4%;" width="932" height="217" border="0"/>);
1;