/*
#############################################
#  .window		                    #
#  #######################################  #
#  #.tab	                         #  #   
#  #######################################  #
#  #.menu                  #.content     #  #
#  # ##################### #             #  # 
#  # #.menuContainer     # #             #  #
#  # #.verticalMenuLayout# #.ShowTables  #  #
#  # #.menuCaption       # #.caption     #  #
#  # #.menuContent       # #             #  #
#  # ##################### #             #  #
#  #                       #             #  #
#  #######################################  #
#                                           #
#############################################
*/
body{
background-image: radial-gradient( ellipse,rgba(233, 123, 0,1) 20%, #2b4569 60%);
background-size:100%;
background-attachment:fixed;
font-family:sans-serif;
color:black;
text-align:left;
vertical-align:middle;
padding-top:0.2em;
font-size:1em;
font-size:1.2em;
line-height:1.5em;
margin:0;
}
/* "Haupt Inhalt" */
.content{
padding-bottom: 0%;
padding-left: 2%;
padding-right:2%;
padding-top: 0%;
text-align:center;
min-height:800px;
background-color:rgba(255,255,255,0.4);
vertical-align:top;
overflow: auto;
}
.toolbar{
padding:1%;
background-color:silver; 
text-align:right;
transition-property: all;
transition-duration: .5s;
max-height:24px; 
height:24px; 
min-height:2px;
transition-timing-function: cubic-bezier(0, 1, 0.5, 1);
line-height: 1.8em;
}
.toolbar.closed {
width:100%;
height:0%;
padding:0%;
background-color:silver;
}
td.header{
  text-align:left;
  font-size:1.1em;
}
.toolbar2{
height:24px;
padding:1%;
background-color:silver; 
text-align:right;
transition-property: all;
transition-duration: .5s;
transition-timing-function: cubic-bezier(0, 1, 0.5, 1);

}
.toolbar2.closed {
width:100%;
height:0%;
padding:0%;
background-color:silver;
/*transition-property: all;
transition-duration: .5s;
transition-timing-function: cubic-bezier(0, 1, 0.5, 1);*/
}
td.top{
  
}
tr.top{
  border-top:1px solid black;
}
.pagePerSite{
  width:50%;
  float:right;
  text-align:right;
}
.makePages{
 width:50%;
 text-align:left;
 float:left
}

/* Export von SQL */
.dumpTextarea{
-moz-border-radius:15px;
-webkit-border-radius:15px;
border-radius:15px;
padding-top:1em;
width:100%;
height:800px;
overflow:auto;
}
.dumpBox{
width:100%;
padding-top:5px;
padding-right:2px;
overflow:auto;
}
.dbHeader{
padding:0px;
margin:0px;
border-radius:15px;
-moz-border-radius:15px;
-webkit-border-radius:15px;
border-spacing: 0px;
border:1px solid #000;
width:100%;
box-shadow:0px 0px 10px black;
background-color:rgba(255, 255, 255,0.3);
}
.MultipleAction{
  width:100%;
  text-align:left;
}
a{
cursor:pointer;
color:black;
}
a:hover{
cursor:pointer;
color:rgba(1,90, 132,0.4);/*blue*/
}
a.link{
cursor:pointer;
color:black;
}
a.link:visited{
cursor:pointer;
color:black;
}
a.link:hover{
cursor:pointer;
color:rgba(233, 123, 0,1);
}
a.menuLink{
color:black;
font-size:1em;
vertical-align:middle;
font-size:2.5em;
}
a.menuLink:hover{
color:rgba(233, 123, 0,1);
font-size:2.5em;
vertical-align:middle;
}
a.menuLink2{
color:black;
font-size:1.2em;
vertical-align:middle;
}
a.menuLink3{
color:black;
font-size:1.2em;
vertical-align:middle;
}
a.catLink{
cursor:pointer;
color:black;
}
a.catLink:hover{
cursor:pointer;
}
a.catLinkPressed{
cursor:pointer;
color:rgba(233, 123, 0,1);
}
a.catLinkPressed:hover{
cursor:pointer;
color:rgba(233, 123, 0,1);
}
/* forms */
input{
-moz-border-radius:2px;
-webkit-border-radius:2px;
border-radius:2px;
vertical-align:top;
border:1px solid black;
color:black;
background-color:rgba(1,90, 132,0.4);/*blue*/
height:1.5em
}
.text{
border:1px solid black;
vertical-align:middle;
border:1px solid black;
color:black;
background-color:rgba(1,90, 132,0.4);/*blue*/
height:1em;
}
select{
-moz-border-radius:2px;
-webkit-border-radius:2px;
border-radius:2px;
vertical-align:middle;
border:1px solid black;
color:black;
background-color:rgba(1,90, 132,0.4);/*blue*/
height:1.5em;
margin: 0.2em;
}
textarea{
border-radius:5px;
-moz-border-radius:5px;
-webkit-border-radius:5px;
border:1px solid black;
vertical-align:top;
border:1px solid black;
color:black;
background-color:rgba(1,90, 132,0.4);/*blue*/
}
textarea.sqlEdit{
border-radius:5px;
-moz-border-radius:5px;
-webkit-border-radius:5px;
border:1px solid black;
vertical-align:top;
border:1px solid black;
color:black;
min-width:98%;
max-width:98%;
min-height:240px;
height:240px;
}
input[type=text] {
height:1.5em;
vertical-align:middle;
border: solid 1px;
background-color:rgba(1,90, 132,0.4);/*blue*/
color:black;
width:99%;
margin:0.2em;
}
input[type=password] {
height:1.5em;
vertical-align:middle;
border: solid 1px;
background-color:rgba(1,90, 132,0.4);/*blue*/
color:black;
width: 99%;
margin: 0.2em;
}
label.caption{
font-size:1.2em;
}
.saveButton{
  text-align:right;
}
input[type=checkbox] {
border-radius:25px;
-moz-border-radius:25px;
-webkit-border-radius:25px;
border: solid 1px;
vertical-align:middle;
background-color:rgba(1,90, 132,0.4);/*blue*/
color:black;
width:1em;
height:1em;
}
input[type=checkbox]:checked {
border-radius:25px;
-moz-border-radius:25px;
-webkit-border-radius:25px;
border: solid 1px;
vertical-align:middle;
background-color:rgba(1,90, 132,0.4);/*blue*/
color:rgba(233, 123, 0,1);
}
input[type=checkbox]:hover {
background-color:rgba(1,90, 132,0.4);/*blue*/
color:rgba(233, 123, 0,1);
box-shadow:0px 0px 10px black; 
}
.markBox{
cursor:pointer;
background-color:rgba(134,23,23,1);
}
td.checkbox{
/*   width:22px; */
}
.markBox:hover{
width:1em;
height:1em;
border:1px solid;
border-radius:25px;
-moz-border-radius:25px;
-webkit-border-radius:25px;
background-color:rgba(134,23,23,1);
cursor:pointer;
}
.markBoxButton{
-moz-border-radius:10px;
-webkit-border-radius:10px;
border-radius:10px;
border:1px solid black;
width:16px;
height:16px;
background-color:rgba(1,90, 132,0.4);/*blue*/
}
input[type=radio] {
background-color:rgba(1,90, 132,0.4);/*blue*/
}

input[type=radio]:checked {
color:rgba(233, 123, 0,1);
background-color:rgba(1,90, 132,0.4);/*blue*/
color:rgba(233, 123, 0,1);
}

input[type=radio]:hover {
background-color:rgba(1,90, 132,0.4);/*blue*/
box-shadow:1px 1px 11px black;
-webkit-box-shadow:1px 1px 1px 1px rgba(0,0,0,0.4);/*black */		
-moz-box-shadow:1px 1px 1px 1px rgba(0,0,0,0.4);/*black */
box-shadow:1px 1px 1px 1px rgba(0,0,0,0.4);/*black */
color:rgba(233, 123, 0,1);
}
.radioButton{
-moz-border-radius:25px;
-webkit-border-radius:25px;
border-radius:25px;
border:1px solid black;
width:1em;
height:1em;
vertical-align:middle;
background-color:rgba(1,90, 132,0.4);/*blue*/
}
.tablelist{
  width:100%;height:100px;
}
input[type="submit"]{
cursor:pointer;
border:1px solid #000;
-moz-border-radius:2px;
-webkit-border-radius:2px;
border-radius:2px;
background-color:rgba(1,90, 132,0.4);/*blue*/
color:black;
font-size:1em;
height:1.5em;
vertical-align:middle;
/* margin: 0.2em; */
}
input[type="submit"]:hover{
-webkit-box-shadow: 1px 1px 1px 1px rgba(0,0,0,0.4);/*black */
-moz-box-shadow: 1px 1px 1px 1px rgba(0,0,0,0.4);/*black */
box-shadow: 1px 1px 1px 1px rgba(0,0,0,0.4);/*black */
color:rgba(233, 123, 0,1);
}
/*<<allgemein*/

.ShowTables{
text-align:center;
margin:5px;
margin: 0.15em 0.15em 1.15em 0.15em;
-moz-border-radius:15px;
-webkit-border-radius:15px;
border-radius:15px;
border-spacing: 0px;
border:1px solid #000;
width:100%;
-webkit-box-shadow:0px 0px 1px rgba(0,0,0,0.4);/*black */
-moz-box-shadow:0px 0px 1px rgba(0,0,0,0.4);/*black */
box-shadow:0px 0px 1px black;
background-color:rgba(255, 255, 255,0.3);
}

td.submit{
  padding-bottom:1%;
  padding-right:1%;
  text-align:right;
}
tr.caption{
text-align:left;
}
td.caption{
background: -webkit-linear-gradient(#e97b00, silver); /* For Safari 5.1 to 6.0 */
background: -o-linear-gradient(#e97b00, silver); /* For Opera 11.1 to 12.0 */
background: -moz-linear-gradient(#e97b00, silver); /* For Firefox 3.6 to 15 */
background: linear-gradient(#e97b00, silver); /* Standard syntax (must be last) */
text-align:left;
height: 1.5em;
padding-left: 0.2em;
padding-right: 0.2em;
border-bottom:1px solid black;
cursor:pointer;
}
td.caption2{
text-align:left;
height: 1.1em;
padding-left: 0.2em;
padding-right: 0.2em;
border-bottom:1px solid black;
background: -webkit-linear-gradient(silver, #e97b00); /* For Safari 5.1 to 6.0 */
background: -webkit-linear-gradient(silver, #e97b00); /* For Safari 5.1 to 6.0 */
background: -o-linear-gradient(silver, #e97b00); /* For Opera 11.1 to 12.0 */
background: -moz-linear-gradient(silver, #e97b00); /* For Firefox 3.6 to 15 */
background: linear-gradient(silver, #e97b00); /* Standard syntax (must be last) */
}
td.caption3{
text-align:left;
height: 1.1em;
padding-left: 0.2em;
padding-right: 0.2em;
}
/*opera*/
td.captionRadius{
-webkit-border-top-left-radius:15px;  
-webkit-border-top-right-radius:15px;
-moz-border-top-left-radius:15px;  
-moz-border-top-right-radius:15px;
border-top-left-radius:15px;  
border-top-right-radius:15px;
background: -webkit-linear-gradient(#e97b00, silver); /* For Safari 5.1 to 6.0 */
background: -o-linear-gradient(#e97b00, silver); /* For Opera 11.1 to 12.0 */
background: -moz-linear-gradient(#e97b00, silver); /* For Firefox 3.6 to 15 */
background: linear-gradient(#e97b00, silver); /* Standard syntax (must be last) */
cursor:pointer;
}
.popupCaption{
-webkit-border-top-left-radius:15px;  
-webkit-border-top-right-radius:15px;
-moz-border-top-left-radius:15px;  
-moz-border-top-right-radius:15px;
border-top-left-radius:15px;  
border-top-right-radius:15px;
padding:0.4em;
border-bottom: 1px solid #000;
height:1.5em;
/* width:99%; */
background: -webkit-linear-gradient(#e97b00, silver); /* For Safari 5.1 to 6.0 */
background: -o-linear-gradient(#e97b00, silver); /* For Opera 11.1 to 12.0 */
background: -moz-linear-gradient(#e97b00, silver); /* For Firefox 3.6 to 15 */
background: linear-gradient(#e97b00, silver); /* Standard syntax (must be last) */
}
td.captionLeft{
border-top-left-radius:15px;
-webkit-border-top-left-radius:15px;  
-moz-border-top-left-radius:15px;
cursor:pointer;
}
td.captionRight{
border-top-right-radius:15px;  
-webkit-border-top-right-radius:15px;
-moz-border-top-right-radius:15px;
cursor:pointer;
}
td.values{
color:black;
text-align:left;
padding-left: 0.2em;
padding-right: 0.2em;
}
td.smallWnd{
  padding:1%;
  text-align:center;
}
td.right{
text-align:right;
padding-right:0.8em;
}

tr.overDb{
color:rgba(233, 123, 0,1);/*orange*/
/*background-color:rgba(1,90, 132,0.4);/*blue*/*/
}
tr.overDb:hover{
color:rgba(233, 123, 0,1);/*orange*/
/*background-color:rgba(1,90, 132,0.4);/*blue*/*/
}
td.overDb{
color:rgba(233, 123, 0,1);/*orange*/
background-color:rgba(1,90, 132,0.4);/*blue*/
}
a.currentLink{
cursor:pointer;
color:rgba(1,90, 132,0.4);/*blue*/
}
a.currentLink:hover{
cursor:pointer;
color:rgba(1,90, 132,0.4);/*blue*/
}
/*<<allgemein*/
/* datenbank headline */
.captionLink{
color:#000;
}
.captionLink:hover{
color:#2b4569;
}
.popup{
z-index:1;
position:fixed;
left:0px;
top:0px;
width:100%;
height:1000px;
background-color:rgba(255,255,255,0.7);
/* background-image:url('/mysql.png'); */
opacity:0.9;
background-size:100%;
background-position:top;
}
.popupContent1{
position:relative;
left:25%;
top:100px;
border:1px solid;
border-radius:15px;
-webkit-border-radius:15px; 
-moz-border-radius:15px;
/* padding:1%; */
opacity:0.9;
width:50%;
background-color:rgba(255,255,255,0.9);
}
.closeButton{
width:1.5em;
height:1.5em;
border:2px solid;
border-radius:25px;
-webkit-border-radius:25px; 
-moz-border-radius:25px;
background-color:#8fb2c5;/*blue*/
color:black;
cursor:pointer;
text-align:center;
}
.closeButton:hover{
width:1.5em;
height:1.5em;
border:2px solid;
border-color:black;
border-radius:25px;
-webkit-border-radius:25px; 
-moz-border-radius:25px;
background-color:#8fb2c5;/*blue*/
color:rgba(233, 123, 0,1);/*orange*/
cursor:pointer;
text-align:center;
box-shadow:1px 1px 1px 1px rgba(0,0,0,0.4);/*black */ 
}
.popupContent{
text-align:center;
width:100%;
/* overflow:auto; */
}
/* //sidebar Menu */
.menuCaption{
cursor:pointer;
}
.menuContent{
width:100%;
text-align:left;
/* padding:4%; */
}
.verticalMenuLayout{
width:80%;
text-align:center;
left:5%;
border: 1px solid;
border-radius:15px;
-webkit-border-radius:15px; 
-moz-border-radius:15px;
padding:4%;
box-shadow:1px 1px 1px 1px rgba(0,0,0,0.4);/*black */ 
-moz-box-shadow:1px 1px 1px 1px rgba(0,0,0,0.4);/*black */ 
-webkit-box-shadow:1px 1px 1px 1px rgba(0,0,0,0.4);/*black */ 
}
.menuContainer{
padding:4%;

}
textarea.sqlEdit{
border-radius:5px;
-webkit-border-radius:5px; 
-moz-border-radius:5px;
padding:5px;
width:100%;
height:253px;
}
select.sqlEdit{
  width:100%;
  height:119px;
}
select.keyWords{
  width:100%;
  height:238px;
}

/* <<form container */
.query{
color:black;
/* background-color:white; */
text-align:center;
}
.searchForm{
  margin:1%;
  width: 98%;
}
.dbForm{
  padding:1%;
  text-align:center;
  width:98%;
}
.EditEntry{
text-align: center;
margin-top: 1.5em;
}
.CreateDatabase{
text-align:left;
left:5%;
padding:4%;
} 
.CreateUser{
text-align:left;
left:5%;
padding:4%;
} 
.CreateTable{
text-align:left;
left:5%;
padding:4%;
}
.ChangeCurrentDb{
text-align:left;
left:5%;
padding:4%;
}
.SqlEditor{
width:100%;
text-align:center;
padding:4%;
}
.SQLRIGHTS{
width:80%;
text-align:center;
left:5%;
padding:4%;

}
.execsql{
text-align:left;
min-height:0%;
}
/* Sidebar */
.menu{
text-align:center;
background-color:rgba(255,255,255,0.9);
border:2px solid;
border-top-right-radius:25px;
border-bottom-right-radius:25px;
-moz-border-top-right-radius:25px;
-moz-border-bottom-right-radius:25px;
-webkit-border-top-right-radius:25px;
-webkit-border-bottom-right-radius:25px;
overflow:auto;
overflow-x: hidden;
transition-property: all;
transition-duration: .5s;
transition-timing-function: cubic-bezier(0, 1, 0.5, 1);
width:25%;
top:1em;
left:-2px;
position:absolute;
box-shadow:1px 1px 1px 1px rgba(0,0,0,0.4);/*black */ 
-moz-box-shadow:1px 1px 1px 1px rgba(0,0,0,0.4);/*black */ 
-webkit-box-shadow:1px 1px 1px 1px rgba(0,0,0,0.4);/*black*/ 
opacity:0.9;
padding-bottom:1%;
}
.menu.closed {
width:2%;
height:90%;
}
.cnt{
text-align:center;
background-color:rgba(255,255,255,0.9);
overflow-x: hidden;
transition-property: all;
transition-duration: .5s;
transition-timing-function: cubic-bezier(0, 1, 0.5, 1);
height:80px;
padding-bottom:4%;
}
.cnt.closed {
/* width:10%; */
height:1px;
}
.menupoint{
text-align:left;
font-size:1.1em;
line-height:1.1em;
cursor:pointer;
}
/* <<TabWidget actions.xsl */
.menupoint:hover{
text-align:left;
font-size:1.1em;
line-height:1.1em;
cursor:pointer;
color:rgba(233, 123, 0,1);
}
.dynamicLink{
font-size:1.1em;
line-height:1.1em;
color:rgba(233, 123, 0,1);/*orange*/
cursor:pointer;
}
a.menuLink{
font-size:1.1em;
line-height:1.1em;
color:black;
cursor:pointer;
}
a.menuLink:hover{
font-size:1.1em;
line-height:1.1em;
cursor:pointer;
color:rgba(233, 123, 0,1);/*orange*/
}
td.headerItem{
font-size:1.1em; 
line-height:1.1em;
border-left:2px solid;
border-top:2px solid;
border-right:2px solid;
border-bottom:2px solid;
border-top-left-radius:10px;
border-top-right-radius:10px;
-moz-border-top-left-radius:10px;
-moz-border-top-right-radius:10px;
-webkit-border-top-left-radius:10px;
-webkit-border-top-right-radius:10px;
border-color:#000;
background-color:rgba(58,127,160,0.3);
text-align:center;
padding:2px;
}
td.headerItemHover{
font-size:1.1em;
line-height:1.1em;
border-left:2px solid;
border-top:2px solid;
border-right:2px solid;
border-top-left-radius:10px;
border-top-right-radius:10px;
-moz-border-top-left-radius:10px;
-moz-border-top-right-radius:10px;
-webkit-border-top-left-radius:10px;
-webkit-border-top-right-radius:10px;
background-color:rgba(255,255,255,0.4);
border-color: #000;
text-align:center;
padding:2px;
}
td.headerItemUnderline{
border-bottom:2px solid;
}
table.tabwidget{
padding:0;
margin:0;
border-spacing:0px;
vertical-align:top;
width:100%;
}
/* TabWidget actions.xsl>> */
/* Menu Layout menu.xsl */
table.verticalMenuLayout{
padding:5%;
margin:0;
border-spacing:0px;
vertical-align:top;
width:90%;
background-color:rgba(255,255,255,0.9);
}
/*index.html main window*/
.window{
overflow:auto;
width:100%;
text-align:left;
vertical-align:middle;
min-height:800px;
}
/* make Pages Start < 1 2 3 4 > */ 
.pages{
width:100%;
padding:0.5em;
min-height:0em;
}
a.menuLink2{
color:rgba(233, 123, 0,1);/*orange*/
font-size:1.1em;
line-height:1.1em;
vertical-align:middle;
}
.toolbarButton{
border:1px solid silver;
color:#000;
padding:0.1em;
margin-left:0.1em;
font-size:1.1em;
line-height:1.4em;
}
.toolbarButton:hover{
-webkit-box-shadow:1px 1px 1px 1px rgba(0,0,0,0.4);/*black */		
-moz-box-shadow:1px 1px 1px 1px rgba(0,0,0,0.4);/*black */
box-shadow:1px 1px 1px 1px rgba(0,0,0,0.4);/*black */
border:1px solid rgba(233, 123, 0,1);
color:rgba(233, 123, 0,1);

}


a.menuLink3{
color:black;
font-size:1.1em;
line-height:1.1em;
vertical-align:middle;
}
a.menuLink2:hover{
color:rgba(233, 123, 0,1);/*orange*/
font-size:1.1em;
line-height:1.1em;
vertical-align:middle;
}
a.menuLink3:hover{
color:rgba(233, 123, 0,1);/*orange*/
font-size:1.1em;
line-height:1.1em;
vertical-align:middle;
}
/* Animation die beim laden angezeigt wird  */
#animationContainer{
}
.animationBox{
position:static;
border:1px solid;
background-color:white;
margin:5px; 
float:left;
width:25px;
height:25px;
opacity:0.1;
border-radius:25px;
-moz-animation-name:animation;
-moz-animation-duration:1.3s;
-moz-animation-iteration-count:infinite;
-moz-animation-direction:linear;
-moz-transform:scale(0.7);
-webkit-animation-name:animation;
-webkit-animation-duration:1.3s;
-webkit-animation-iteration-count:infinite;
-webkit-animation-direction:linear;
-webkit-transform:scale(0.7);
-ms-animation-name:animation;
-ms-animation-duration:1.3s;
-ms-animation-iteration-count:infinite;
-ms-animation-direction:linear;
-ms-transform:scale(0.7);
-o-animation-name:animation;
-o-animation-duration:1.3s;
-o-animation-iteration-count:infinite;
-o-animation-direction:linear;
-o-transform:scale(0.7);
animation-name:animation;
animation-duration:1.3s;
animation-iteration-count:infinite;
animation-direction:linear;
transform:scale(0.7);
}

#animation_1{
-moz-animation-delay:0.10s;
-webkit-animation-delay:0.10s;
-ms-animation-delay:0.10s;
-o-animation-delay:0.10s;
animation-delay:0.10s;
}

#animation_2{
-moz-animation-delay:0.15s;
-webkit-animation-delay:0.15s;
-ms-animation-delay:0.15s;
-o-animation-delay:0.15s;
animation-delay:0.15s;
}

#animation_3{
-moz-animation-delay:0.20s;
-webkit-animation-delay:0.20s;
-ms-animation-delay:0.20s;
-o-animation-delay:0.20s;
animation-delay:0.20s;
}
#animation_4{
-moz-animation-delay:0.25s;
-webkit-animation-delay:0.25s;
-ms-animation-delay:0.25s;
-o-animation-delay:0.25s;
animation-delay:0.25s;
}
@-moz-keyframes animation{
  0%{
    -moz-transform:scale(1.2);
    opacity:1;
  }
  100%{
    -moz-transform:scale(0.7);
    opacity:0.1;
  }
}

@-webkit-keyframes animation{
0%{
  -webkit-transform:scale(1.2);
  opacity:1;
}
100%{
  -webkit-transform:scale(0.7);
  opacity:0.1;
}
}
@-ms-keyframes animation{
  0%{
    -ms-transform:scale(1.2);
    opacity:1;
  }
  100%{
    -ms-transform:scale(0.7);
    opacity:0.1;
  }
}
@-o-keyframes animation{
  0%{
    -o-transform:scale(1.2);
    opacity:1;
  }
  100%{
    -o-transform:scale(0.7);
    opacity:0.1;
  }
}
@keyframes animation{
  0%{
    transform:scale(1.2);
    opacity:1;
  }
  100%{
    transform:scale(0.7);
    opacity:0.1;
  }
}
.waid{
  padding-top:20%;
  margin-left: auto;
  margin-right: auto;
  width: 150px;
  height:600px;
}
table.ExecSql{
  width:100%;
  padding:1%;
}
.ExecSql{
text-align:center;
padding:1%;
margin-top:1.5em;
margin: 0.7em;
padding: 1%;
width: 96%;
-moz-border-radius:15px;
-webkit-border-radius:15px;
border-radius:15px;
border-spacing: 0px;
border:1px solid #000;
overflow:auto;
-webkit-box-shadow:0px 0px 1px rgba(0,0,0,0.4);/*black */
-moz-box-shadow:0px 0px 1px rgba(0,0,0,0.4);/*black */
box-shadow:0px 0px 1px black;
background-color:rgba(255, 255, 255,0.3);
}