$VAR1 = {
          'database' => {
                          'CurrentUser' => 'root',
                          'CurrentHost' => 'localhost',
                          'host' => 'localhost',
                          'user' => 'root',
                          'CurrentDb' => 'LZE',
                          'password' => 'keinz',
                          'name' => 'LZE',
                          'CurrentPass' => 'keinz'
                        },
          'language' => 'en',
          'config' => '/var/www/cgi-bin/config/settings.pl',
          'actions' => '/var/www/cgi-bin/config/actions.pl',
          'floodtime' => 10,
          'scriptAlias' => 'cgi-bin',
          'cgi' => {
                     'style' => 'mysql',
                     'bin' => '/var/www/cgi-bin',
                     'expires' => '+1y',
                     'DocumentRoot' => '/var/www/htdocs',
                     'cookiePath' => '/',
                     'alias' => 'cgi-bin',
                     'title' => 'MySQL::Admin',
                     'serverName' => 'http://localhost'
                   },
          'admin' => {
                       'email' => 'dirk.lze@gmail.com',
                       'name' => 'Lindner',
                       'firstname' => 'Dirk',
                       'password' => 'testpass'
                     },
          'session' => '/var/www/cgi-bin/config/session.pl',
          'version' => '0.73',
          'translate' => '/var/www/cgi-bin/config/translate.pl'
        };
$m_hrSettings =$VAR1;