[header]
[pages/]
[/header]
[links]
<a class="menuLink3" href="[href/]">[title/]</a>
[/links]
[currentLinks]
<a class="menuLink2" href="[href/]">[title/]</a>
[/currentLinks]
[previous]
<a class="menuLink2" href="[href/]"><img src="style/mysql/prev.png" alt="Previous" border="0" title="Previous" style="cursor:pointer;"/></a>
[/previous]
[next]
<a class="menuLink2" href="[href/]"><img src="style/mysql/next.png" alt="Next" border="0" title="Next" style="cursor:pointer;"/></a>
[/next]
[footer]
[/footer]
